clear all
set mem 100m
set more off
capture log close

log using $SL_log/chiefs_analysis_nps2007_birth.log, replace

/*--------------------------
This file gets the NPS data ready for analysis
---------------------------*/

/*----------------------------------
2. Basic Indicators from NPS 2007

Definitions of the indicators discussed below.
-----------------------------------*/

use $SL_data/nps-2007_hh_clean.dta

*Merging on Chiefdom of Birth for Education Regressions
rename a8 chiefcode
sort chiefcode
merge chiefcode using $SL_data/chiefs_survey_clean_out.dta

drop if _merge!=3
drop _m

*0. Demographics
xtile acat = a3, n(6)
tab acat, gen(acat_)

rename a3 age
gen age2 = age^2

gen female = (a2==2)
gen christian = inlist(a6,11,12,13,14,15,16,19)

tab a7, gen(ethnicity)
drop ethnicity1 ethnicity2 ethnicity16 ethnicity17

*1. Education
gen tertiary = inlist(a4,31,32,33,34)
gen secondary = inlist(a4,21,22,23,24,25,26) | tertiary==1
gen primary = inlist(a4,11,12,13,14,15,16,17) | secondary ==1

recode primary secondary tertiary (nonmissing = .) if a4==99 | missing(a4)==1

*2. Wealth
*Index of asset wealth in [0,1]; (equal weights to ownership of bicycle, mobile phone, generator, umbrella, radio)
gen wealth = (a10a + a10b + a10c + a10d + a10e + a10f + a10g + a10h)/8

rename a10a bike
rename a10b phone
rename a10c generator
rename a10d cartruckmoto
rename a10e fan
rename a10f umbrella
rename a10g tv
rename a10h radio


*Quality indicies of floor, roof and wall quality; in [0,1].
*Is floor cement/til/or concrete?
gen nicefloor = (a22 != 1)
*Is roof not thatched?
gen niceroof = (a23 == 2 | a23 == 3 | a23 == 5)
*Is wall made of cement?
gen nicewall = (a24 == 5)

*Avearge of floor, roof and wall induces; in [0,1]
gen nicehouse = (nicefloor + niceroof + nicewall)/3

*3. Ruling Family Houses
*Is the household head (randomly selected) a member of a ruling house; in [0,1]
gen member = a31

*4. Cash Crop?
*In the last year, have you sold any agricultural produce? [0,1]
gen sell_crop = b3

*5. Wage Labour?
*During the past year, have you or anyone in yourhousehold done any work for which a salary or wage was paid? [0,1]
gen wage_work = b11

*6. Know Paramount Chief
*Do you personally know the paramount chief
gen knowchief = g2

*8. Chief Listens
*Agree or disagree: "Do you think the PC listents to what people in this town/neighborhood say or what they need?"
gen chieflistens = g5

*9. Been to meeting with PC
*In the past year, have you talked with the PC or been to a meeting organized by the PC [0,1]
gen chiefmeeting = g4

*10. Road Brushing
*Have you done any road brushing or town cleaning in the past month [0,1]? Key indicator of collective action from Miguel, Glennerster Rothenberg.
gen roadbrush = c13

*11. Community Meetings
*Have you attended any community meetings in the past month? Another key indicator of collective action from Miguel. 
gen comm_meet = c15a

*12. Provided Labor
*Have you provided labor to any community project (such as school construction or community farm)?
recode c14_time (. .a .b = 0)
gen provide_labor = c14_time

*13. Group membership
*Labor gang
gen labor_gang = c9a
*Traditional Society
gen secret_society = c10a

*Farmers Group
gen farmer_group = c3a

*School Committee
gen school_group = c7a

*Putnam Goups
recode c1a c2a (.b = 0)

gen womens_group = c1a
gen youth_group = c2a
gen religious_group = c4a
gen osusu = c5a
gen union = c6a
gen political_group = c8a

gen bonding = (c1a + c2a + c3a + c4a + c5a + c6a + c7a + c8a + c9a + c10a)/10

gen collective = (roadbrush + c14)/2


*12. Enrollment
*Share of school age children in household enrolled in school. 
gen enrollment = e2/e1
replace enrollment = . if enrollment > 1

*13. Disputes
*For the last major dispute your household had with another houesehold (money buisness, theft, child support, inheritance, land dispute, assault) did you first take this argument to anyone in the traditional authority (village chief, section chief, or PC)?
gen dispute_to_chiefs = ( inlist(d9,1,2,3))
replace dispute_to_chiefs = .  if missing(d9)==1

*14. War Exposure
*Was someone in your household injured during the war? [0,1]
gen injured = f4
*Was someone in your household killed during the war
gen killed = f5
*Was your house (or part of your compound) ever burned down in the war?  [0,1]
gen burned = f6
*Average of above three indicies; in  [0,1]
gen war_index = (f4 + f5 + f6) / 3

*15. Political attidues
*Agree that violence is never justified in politics. [0,1]
gen violence_justified = (g32==1 | g32==4)

*Agree that "we should be more active in questioning the actions of leaders"
gen question_leaders = (g33 == 1 | g33 == 4)

*Agree that "In our country these days, we should have more respect for authority"
gen respect_authority = (g33 == 2 | g33 == 4)

*Agree that "responsible young people can be good leaders"
gen young_people_can_lead = (g35==1 | g35==4)

*Agree that "only older people are mature enough leaders"
gen only_old_can_lead = (g35==2 | g35==4)

*Agree that "In our country, it's normal to pay a bribe to a government official to encourage them"
gen normal_to_bribe = (g37 == 1 | g37==4)

*Agree that "It's wrong to pay a bribe to any government official"
gen wrong_to_bribe = (g37 == 2 | g37 == 4)

gen church_mosque = (c12)

*Bridging:
drop comm_meet
gen commmeet = c15a
gen comment = (c15a == 1 & c15b==1)
gen chiefmeet = g4
gen chiefhqvisit = (g3 == 1 & g3_month>1116)

*Making:
gen lchqvisit = (g10 == 1 & g10_month>1116)
gen lcmeet = g12
recode lcmeet (.b = 0)
gen lcboard = g11

loc make lchqvisit lcmeet lcboard

gen bridging = (lcmeet + commmeet + chiefmeet )/3

*Roles:
gen role_pc = a32a
gen role_wdc = a32b
gen role_headman = a32c
gen role_vdc = a32d
gen role_imam = a32e
gen role_secsoc = a32f
gen role_lc = a32g
gen role_women = a32h
gen role_youth = a32i
gen role_court = a32j
gen role_farmer = a32k


loc roles role*

*Trust:
gen trust_peopleloc = (c16a ==1)
gen trust_peoplenloc = (c16b==1)
gen trust_chiefdom = (c16c==1)
gen trust_police = (c16d==1)
gen trust_lc= (c16e==1)
gen trust_cent = (c16f==1)
gen trust_ngo = (c16g==1)
gen trust_lcourt = (c16h==1)
gen trust_mag = (c16i==1)

gen chief_needs = g5
gen chief_bad = (g6==4 | g6 == 3)

gen lc_needs = g13
gen lc_bad = ( g14==4 | g14==3)

gen ftown_needs = g24
gen ftown_bad = (g24 == 3 | g25==4)

gen pessimist = (g31==3)


loc trust trust* *_needs *_bad pessimist
*loc trust *_bad pessimist

gen wdc = (g19)

lab var school_group "Respondent is member of Parent Teacher Association"
lab var roadbrush "Respondent has participated in road brushing in last month"
lab var chiefmeet "Respondent has spoken to/been to a meeting organized by the Paramount Chief in the past year"
lab var lcmeet "Respondent has spoken to/been to a meeting organized by the Local Council in the past year"
lab var commmeet "Respondent has been to a community meeting in the past year"
lab var wdc "Respondent has spoken to/been to a meeting organized by the Ward Development Committee in the past year"

lab var chief_bad "In hypothetical question, respondent believes chief would embezzle all development grant money"
lab var chief_needs "Respondent agrees that the PC listents to what people in this village say or what they need"

lab var question_leaders "Respondent agrees that we should be more active in questioning the actions of leaders"
lab var respect_authority "Respondent agrees that in our country these days, we should have more respect for authority"
lab var young_people_can_lead "Respondent agrees that responsible young people can be good leaders"

save $SL_data/chiefs_nps_birth_rr.dta, replace

log close
