clear all
set matsize 11000
set mem 100m
set more off
capture log close

log using $SL_log/chiefs_analysis_attitudes_bias_test.log, replace

/*--------------------------
This file tests for the potential bias in our social activties and attitudes indicators.

Last Edit: TR, 5/5/13
---------------------------*/

use $SL_data/chiefs_nps_birth_rr.dta, replace

/*------------
Preliminaries
------------*/

loc controls female age age2 ethnicity*
loc study_controls n_chiefs amalgamation
loc district_fe dist? dist??

lab var n_chiefs "Chiefs Observed"
lab var amalgamation "Amalgamation"
lab var fam_num_ln "Ln(Families)"

/*-------------------------------------------------
Predicted Outcomes with Bootstrapped Standard Errors
---------------------------------------------------*/
/*Core Parameters*/
loc straps = 1000
loc dec = 3
set seed 1000
loc counter=0

foreach y of varlist respect_authority bridging bonding collective {

/*2. Bootstrapping Standard Errors*/
matrix coeffs = J(`straps',3,.)
matrix coeffs_d = J(`straps',3,.)
foreach k of numlist 1/`straps'{

   preserve
   bsample, cluster(chiefcode)

   /*Predicting on Bootstrapped Sample*/
   reg `y' mitchell_km coast_dist rail_dist dist_min mining_1930 dist? dist?? [pw = inv_prob] 
  
   predict `y'_p`k'  if e(sample), xb
   keep if `y'_p`k' !=.
   egen tag = tag(chiefcode)
   keep if tag==1

   reg `y'_p`k' fam_num_ln `study_controls' , r 
     capture matrix coeffs[`k',1] = _b[fam_num_ln]
     capture matrix coeffs[`k',2] = _b[n_chiefs]
     capture matrix coeffs[`k',3] = _b[amalgamation]
  
   reg `y'_p`k' fam_num_ln `study_controls' `district_fe' , r 
     capture matrix coeffs_d[`k',1] = _b[fam_num_ln]
     capture matrix coeffs_d[`k',2] = _b[n_chiefs]
     capture matrix coeffs_d[`k',3] = _b[amalgamation]
   restore
 }

/*Outputting Standard Errors*/
preserve
clear
svmat coeffs
foreach i of numlist 1/3{
  sum coeffs`i', d
  loc se`i' = round( r(sd),0.001)
}

save $SL_out/chiefs_bias_bstrap_`y', replace

clear
svmat coeffs_d
foreach i of numlist 1/3{
  sum coeffs_d`i', d
  loc se_d`i' = round( r(sd),0.001)
}

save $SL_out/chiefs_bias_bstrap_d_`y', replace
restore

/*2. Creating Predicted Values Using Original Sample*/
reg `y' mitchell_km coast_dist rail_dist dist_min mining_1930 dist? dist?? [pw = inv_prob] 
predict `y'_p  if e(sample), xb

/*3. Regressing Original Predictions on Number of Families and Outputting with S.E.*/
preserve
keep if `y'_p !=.
egen tag = tag(chiefcode)
keep if tag==1

if `counter' == 0{
  loc cond replace
}
else{
  loc cond
}

loc counter = `counter' + 1

/*reg `y'_p fam_num_ln `study_controls'  , r
outreg2 using "$SL_out/chiefs_activities_bias_test.tex", `cond' tex(frag) drop(`controls' `elite' `district_fe' ) dec(`dec')  ctitle("`y' bias") nonotes nocons  sortvar(fam_num_ln `elite')  addtext(District FE , NO,  Family se, `se1' , N_chiefs se, `se2', Amalgamation se, `se3' ) addnote("Bootstrapped standard errors use 500 iterations") label */

reg `y'_p fam_num_ln `study_controls' `district_fe' , r 
outreg2 using "$SL_out/chiefs_activities_bias_test.tex",  tex(frag) drop(`controls' `elite' `district_fe' ) dec(`dec')  ctitle("`y' bias") nonotes nocons  sortvar(fam_num_ln `elite')  addtext(District FE ,YES,  Family se, `se_d1' , N_chiefs se , `se_d2', Amalgamation se, `se_d3' ) addnote("Bootstrapped standard errors use 500 iterations") label
restore

}

log close
