clear all
set mem 1500m

/*----------------------------------------------------------------------
This file creates table 6 using 
the census data and the nps matched on chiefdom birth
-------------------------------------------------------------------------*/

loc exocontrol mitchell_km coast_dist rail_dist river_dist dist_min mining_1930


/*-------------------
A. Non-Agricultural Employment (Birth)
----------------------*/

use $SL_data/chiefs_census_2004_birth.dta, clear

loc outcome nonag
loc kitchen_sink female age age2 ethnicity*
  loc cond 10
  
rename chiefcode_birth chiefcode

lab var fam_num_ln "Ln(Families)"
lab var amalgamation "Amalgamation"
lab var n_chiefs "Number of chiefs recalled"

/*Mean*/
sum `outcome' if missing(fam_num_ln)==0 & age>`cond'

/*1. Study Controls, District FE,  Demographic Controls*/

/*Without Historical Controls*/
  reg `outcome' fam_num_ln  amalgamation  n_chiefs dist1-dist12 `kitchen_sink'   if  age>`cond',  r  cluster(chiefcode)

outreg2 using "$SL_out/chiefs_table6_rr3", replace tex(frag) keep (fam_num_ln  n_chiefs amalgamation) dec(3) nocons ctitle("`outcome'") label addtext(District fixed effects, YES, Demographic controls, YES, Historical Controls, NO)  sortvar(fam_num_ln amalgamation n_chiefs) noaster
  
/*With Historical Controls*/
  reg `outcome' fam_num_ln  amalgamation  n_chiefs dist1-dist12 `kitchen_sink'  `exocontrol'  if  age>`cond' ,  r  cluster(chiefcode)

outreg2 using "$SL_out/chiefs_table6_rr3_exocontrols", replace tex(frag) keep (fam_num_ln  n_chiefs amalgamation) dec(3) nocons  ctitle("`outcome'") label addtext(District fixed effects, YES, Demographic controls, YES, Historical Controls, YES)  sortvar(fam_num_ln amalgamation n_chiefs) noaster

/*2. Study Controls, District FE, Demographic Controls, Researcher FE*/
reg `outcome' fam_num_ln amalgamation n_chiefs  research_dummy*  dist1-dist12 `kitchen_sink'   if  age>`cond' ,  r  cluster(chiefcode)

outreg2 using "$SL_out/chiefs_table6_rr3_researcher_appendix", replace tex(frag) keep (fam_num_ln) dec(3) nocons  ctitle("`outcome'") addtext(District fixed effects, YES, Demographic controls, YES, Researcher FE, YES)  sortvar(fam_num_ln amalgamation n_chiefs) noaster




/*--------------------------
DHS. Wealth
--------------------------*/
use  $SL_data/chiefs_dhs_hh.dta, clear

gen female = (hv219 == 2)
gen age = (hv220)
gen age2 = hv220^2

tab shlang, gen(eth)
drop eth5

loc controls female age age2 eth1 eth2 eth3 eth4
loc district_fe dist? dist??

/*Calculating Mean*/
  mean dhs_wealth_index [pw = hv005]
  matrix av = e(b)
  loc average = round( av[1,1] , 0.01 ) 

*Without Historical Controls*/
   regress dhs_wealth_index fam_num_ln `study_controls' `controls' `district_fe'  [pw = hv005] , cluster( chiefcode) 

outreg2 using "$SL_out/chiefs_table6_rr4", tex(frag) keep (fam_num_ln  n_chiefs amalgamation) dec(3) nocons ctitle("dhs wealth") label addtext(District fixed effects, YES, Demographic controls, YES, Historical Controls, NO)  sortvar(fam_num_ln amalgamation n_chiefs) noaster
  
/*With Historical Controls*/
   regress dhs_wealth_index fam_num_ln `study_controls' `controls' `district_fe' `exocontrol'  [pw = hv005] , cluster( chiefcode) 

outreg2 using "$SL_out/chiefs_table6_rr4_exocontrols",  tex(frag) keep (fam_num_ln  n_chiefs amalgamation) dec(3) nocons  ctitle("dhs_wealth") label addtext(District fixed effects, YES, Demographic controls, YES, Historical Controls, YES)  sortvar(fam_num_ln amalgamation n_chiefs) noaster

/*2. Study Controls, District FE, Demographic Controls, Researcher FE*/
 regress dhs_wealth_index fam_num_ln `study_controls' `district_fe' research_dummy*   [pw = hv005] , cluster( chiefcode) 

outreg2 using "$SL_out/chiefs_table6_rr4_researcher_appendix",  tex(frag) keep (fam_num_ln) dec(3) nocons  ctitle("dhs_wealth") addtext(District fixed effects, YES, Demographic controls, YES, Researcher FE, YES)  sortvar(fam_num_ln amalgamation n_chiefs) noaster


}

/*----------------
B: NPS
-------------------*/

loc controls female age age2 ethnicity*
loc study_controls amalgamation n_chiefs 
loc district_fe dist? dist??

/*B1. Matched on Birth*/
use $SL_data/chiefs_nps_birth_rr.dta, replace

lab var amalgamation "Amalgamation"
lab var n_chiefs "Number of chiefs recalled"

foreach y of varlist wealth nicehouse {

  /*Generating Summary Statistics for Table 1*/
  mean `y' if missing(fam_cat) ==0

  matrix define M = e(b)
  loc mean = round(M[1,1],0.001)

  tabstat `y' [fw = round(inv_prob) ], by(fam_cat) stat(mean sd)
  
/*1. Regression with District FE and Controls*/

/*Without Historical Controls*/  
  reg `y' fam_num_ln `study_controls' `district_fe' `controls'  [pw = inv_prob] , r cluster(chiefcode)

  outreg2 using "$SL_out/chiefs_table6_rr4.tex",  tex(frag) keep(fam_num_ln  n_chiefs amalgamation)  dec(3)  ctitle("`y'") nonotes noaster nocons label  addtext(District fixed effects, YES, Demographic controls, YES, Historical Controls, NO)
  
/*With Historical Controls*/  
  reg `y' fam_num_ln `study_controls' `district_fe' `controls' `exocontrol' [pw = inv_prob] , r cluster(chiefcode)

  outreg2 using "$SL_out/chiefs_table6_rr4_exocontrols.tex",  tex(frag) keep(fam_num_ln  n_chiefs amalgamation)  dec(3)  ctitle("`y'") nonotes noaster nocons label  addtext(District fixed effects, YES, Demographic controls, YES, Historical Controls, YES)

/*2. Regression with Study Controls, District FE, Demographic controls, Researcher FE*/
reg `y' fam_num_ln `study_controls' `district_fe' `controls' research_dummy* [pw = inv_prob] , r cluster(chiefcode)

  outreg2 using "$SL_out/chiefs_table6_rr4_researcher_appendix.tex",  tex(frag) keep(fam_num_ln  n_chiefs amalgamation)  dec(3)  ctitle("`y'") nonotes noaster nocons label  addtext(District fixed effects, YES, Demographic controls, YES, Researcher Fixed Effects, YES)
  
}
