clear all
set mem 1000m
set more off
capture log close

log using $SL_log/chiefs_nps_table468910C_rr.log, replace

/*--------------------------
This file requires calling both
chiefs_nps_rr.dta and chiefs_nps_birth_rr.dta.

To generate table E3 it calls on the census data,
which is confidential.

In addition, it also reports summary statistics
of variables for Table 1.

Last Edit: TR, 5/7/13
---------------------------*/

/*Regression Specification and Outreg Preliminaries*/
loc controls female age age2 ethnicity*
loc study_controls amalgamation n_chiefs 
loc district_fe dist? dist??

loc exocontrol mitchell_km coast_dist rail_dist river_dist dist_min mining_1930

loc elite role_pc member role_headman

loc dec = 3

/*-----------------------------------
Online Appendix Table E3: Social Capital Correlation Coefficients
-----------------------------------*/

loc run = 0
if `run' == 1{
  
/*1. Calling NPS matched on chiefdom of residence*/
use $SL_data/chiefs_nps_birth_rr, replace

loc outcomes  bridging commmeet bonding osusu labor_gang secret_society collective roadbrush
loc devoutcomes primary nicehouse wealth member role_pc role_headman

/*2. Individual Level Correlations: Table 9, Panel A*/
corr `outcomes' `devoutcomes' [fw = round(inv_prob) ] if missing(fam_num)==0

/*3. Getting Chiefdom Averages of Development Indicators for other Correlations*/
preserve
use $SL_data/chiefs_census_2004.dta, clear
replace nonag = . if age<10
replace primary = . if age<12
collapse (mean) nonag primary , by(chiefcode_birth)
rename chiefcode_birth chiefcode
sort chiefcode

tempfile census
save `census'

use $SL_data/chiefs_nps_birth_rr.dta, clear
drop primary
drop if fam_num==.
loc devoutcomes nicehouse wealth member role_pc role_headman
collapse (mean) `outcomes' `devoutcomes' [fw = round(inv_prob)] , by(chiefcode)

sort chiefcode
merge 1:1 chiefcode using `census'
drop if _m !=3

/*4. Aggregate Correlations: Table 9, Panel B*/
loc outcomes  bridging commmeet bonding osusu labor_gang secret_society collective roadbrush
loc devoutcomes primary  nicehouse wealth member role_pc role_headman nonag

corr `outcomes' `devoutcomes'

restore

/*Kill Run Loop*/
}
/*-------------------------------
Table 8: Attitudes 
--------------------------------*/

loc run = 0
if `run' == 1{

/*NPS*/
use $SL_data/chiefs_nps_birth_rr.dta, replace

lab var amalgamation "Amalgamation"
lab var n_chiefs "Number of chiefs recalled"

loc outcomes respect_authority only_old_can_lead

/*Regressions*/
foreach y of varlist `outcomes' {

  /*Generating Summary Statistics for Table 1*/
  mean `y' if missing(fam_cat) ==0

  matrix define M = e(b)
  loc mean = round(M[1,1],0.001)

  tabstat `y' [fw = round(inv_prob) ], by(fam_cat) stat(mean sd)

   /*Adding Replace condition for outreg2*/ 
   if "`y'" == "respect_authority"{
   loc rcond replace
   }
   else{
   loc rcond
   }

/*----------------------------------
PANEL A: Without Historical Controls
------------------------------------*/
  
/*Regression with District FE*/
  reg `y' fam_num_ln `study_controls' `district_fe'  [pw = inv_prob] , r cluster(chiefcode)

  outreg2 using "$SL_out/chiefs_nps_table8_rr.tex", `rcond' tex(frag) keep(fam_num_ln amalgamation n_chiefs) dec(`dec')  ctitle("`y'") nonotes noaster nocons label addtext(District Fixed Effects, YES, Demographic controls, NO, Historical controls, NO)


/*Regression with District FE and Controls*/
  reg `y' fam_num_ln `study_controls' `district_fe' `controls'  [pw = inv_prob] , r cluster(chiefcode)

  outreg2 using "$SL_out/chiefs_nps_table8_rr.tex", tex(frag) keep(fam_num_ln amalgamation n_chiefs) dec(`dec')  ctitle("`y'") nonotes noaster nocons label  addtext(District Fixed Effects, YES, Demographic controls, YES, Historical controls, NO)


/*----------------------------------
PANEL B: With Historical Controls
------------------------------------*/

/*Regression with District FE*/
  reg `y' fam_num_ln `study_controls' `district_fe' `exocontrol' [pw = inv_prob] , r cluster(chiefcode)

  outreg2 using "$SL_out/chiefs_nps_table8_exocontrols_rr.tex", `rcond' tex(frag) keep(fam_num_ln amalgamation n_chiefs) dec(`dec')  ctitle("`y'") nonotes noaster nocons label addtext(District Fixed Effects, YES, Demographic controls, NO, Historical controls, YES)


/*Regression with District FE and Controls*/
  reg `y' fam_num_ln `study_controls' `district_fe' `controls' `exocontrol'  [pw = inv_prob] , r cluster(chiefcode)

  outreg2 using "$SL_out/chiefs_nps_table8_exocontrols_rr.tex", tex(frag) keep(fam_num_ln amalgamation n_chiefs) dec(`dec')  ctitle("`y'") nonotes noaster nocons label  addtext(District Fixed Effects, YES, Demographic controls, YES, Historical controls, YES)

  
/*----------------------------------
PANEL C: Researcher Fixed Effects
------------------------------------*/
  
/*Regression with Study Controls, District FE, Demographic controls, Researcher FE*/
reg `y' fam_num_ln `study_controls' `district_fe' `controls' research_dummy* [pw = inv_prob] , r cluster(chiefcode)

  outreg2 using "$SL_out/chiefs_nps_table8_researcher_rr.tex", `rcond' tex(frag) drop(`controls' `district_fe') dec(`dec')  ctitle("`y'") nonotes noaster nocons label  addtext(District Fixed Effects, YES, Demographic controls, YES, Researcher Fixed Effects, YES, Historical controls, NO)

}

/*Kill Run Loop*/
}


/*-------------------------------
Table 9: Social Capital Outcomes
--------------------------------*/

loc run = 0
if `run' == 1{

use $SL_data/chiefs_nps_birth_rr.dta, replace

lab var amalgamation "Amalgamation"
lab var n_chiefs "Number of chiefs recalled"

loc outcomes bridging commmeet bonding osusu labor_gang secret_society collective roadbrush

/*Regressions*/
foreach y of varlist `outcomes' {

  /*Generating Summary Statistics for Table 1*/
  mean `y' if missing(fam_cat) ==0

  matrix define M = e(b)
  loc mean = round(M[1,1],0.001)

  tabstat `y' [fw = round(inv_prob) ], by(fam_cat) stat(mean sd)

   /*Adding Replace condition for outreg2*/ 
   if "`y'" == "bridging"{
   loc rcond replace
   }
   else{
   loc rcond
   }


/*----------------------------------
PANEL A: Without Historical Controls
------------------------------------*/
  
/*Regression with District FE and Controls*/
  reg `y' fam_num_ln `study_controls' `district_fe' `controls'  [pw = inv_prob] , r cluster(chiefcode)

  outreg2 using "$SL_out/chiefs_nps_table9_rr.tex", `rcond'  tex(frag) keep(fam_num_ln amalgamation n_chiefs) dec(`dec')  ctitle("`y'") nonotes noaster nocons label  addtext(District Fixed Effects, YES, Demographic controls, YES, Historical controls, NO)

/*----------------------------------
PANEL B: With Historical Controls
------------------------------------*/

/*Regression with District FE and Controls*/
  reg `y' fam_num_ln `study_controls' `district_fe' `controls' `exocontrol'  [pw = inv_prob] , r cluster(chiefcode)

  outreg2 using "$SL_out/chiefs_nps_table9_exocontrols_rr.tex", `rcond'  tex(frag) keep(fam_num_ln amalgamation n_chiefs) dec(`dec')  ctitle("`y'") nonotes noaster nocons label  addtext(District Fixed Effects, YES, Demographic controls, YES, Historical controls, YES)

/*----------------------------------
PANEL C: Researcher Fixed Effects
------------------------------------*/
  
/*Regression with Study Controls, District FE, Demographic controls, Researcher FE*/
reg `y' fam_num_ln `study_controls' `district_fe' `controls' research_dummy* [pw = inv_prob] , r cluster(chiefcode)

  outreg2 using "$SL_out/chiefs_nps_table9_researcher_rr.tex", `rcond'  tex(frag) keep(fam_num_ln amalgamation n_chiefs) dec(`dec')  ctitle("`y'") nonotes noaster nocons label  addtext(District Fixed Effects, YES, Demographic controls, YES, Researcher Fixed Effects, YES, Historical Controls, NO)

  
}

/*Kill Run Loop*/
}

/*-------------------------------------------------------
Table E2: Appendix Table, Additional Variables, Social Capital
-------------------------------------------------------*/

loc run = 0
if `run' == 1{

use $SL_data/chiefs_nps_birth_rr.dta, replace

lab var amalgamation "Amalgamation"
lab var n_chiefs "Number of chiefs recalled"

loc outcomes commmeet lcmeet chiefmeet roadbrush c14 trust_peoplenloc trust_peopleloc trust_chief chief_bad

/*Regressions*/
foreach y of varlist `outcomes' {

  /*Generating Summary Statistics for Table 1*/
  mean `y' if missing(fam_cat) ==0

  matrix define M = e(b)
  loc mean = round(M[1,1],0.001)

  tabstat `y' [fw = round(inv_prob) ], by(fam_cat) stat(mean sd)
   
  /*Regression with District FE*/
  reg `y' fam_num_ln `study_controls' `district_fe' `controls' [pw = inv_prob] , r cluster(chiefcode)

   /*Adding Replace condition for outreg2*/ 
   if "`y'" == "commmeet"{
   loc rcond replace
   }
   else{
   loc rcond
   }

  outreg2 using "$SL_out/chiefs_nps_appendix_tableE2_bridgingcoll_rr.tex", `rcond'  tex(frag) drop(`controls' `district_fe') dec(`dec')  ctitle("`y'") nonotes noaster nocons label  addtext(District fixed effects, YES, Demographic controls, YES, Mean of Outcome, `mean') 

}

/*Kill Run Loop*/
}


loc run = 0
if `run' == 1{

use $SL_data/chiefs_nps_birth_rr.dta, replace

lab var amalgamation "Amalgamation"
lab var n_chiefs "Number of chiefs recalled"

loc outcomes osusu labor_gang secret_society union political_group womens_group youth_group farmer_group religious_group school_group 

/*Regressions*/
foreach y of varlist `outcomes' {

  /*Generating Summary Statistics for Table 1*/
  mean `y' if missing(fam_cat) ==0

  matrix define M = e(b)
  loc mean = round(M[1,1],0.001)

  tabstat `y' [fw = round(inv_prob) ], by(fam_cat) stat(mean sd)
   
  /*Regression with District FE*/
  reg `y' fam_num_ln `study_controls' `district_fe' `controls' [pw = inv_prob] , r cluster(chiefcode)

   /*Adding Replace condition for outreg2*/ 
   if "`y'" == "osusu"{
   loc rcond replace
   }
   else{
   loc rcond
   }

  outreg2 using "$SL_out/chiefs_nps_appendix_tableE2_bonding_rr.tex", `rcond'  tex(frag) drop(`controls' `district_fe') dec(`dec')  ctitle("`y'") nonotes noaster nocons label  addtext(District fixed effects, YES, Demographic controls, YES, Mean of Outcome, `mean') 

}

/*Kill Run Loop*/
}


/*--------------------------------------------------
Appendix Table H2: Modernization Hypohtesis Check
---------------------------------------------------*/

loc run = 0
if `run' == 1{

use $SL_data/chiefs_nps_birth_rr.dta, replace

/*Keeping Non Movers*/
keep if chief_2004census == chiefcode

lab var amalgamation "Amalgamation"
lab var n_chiefs "Number of chiefs recalled"

loc outcomes bridging bonding collective respect_authority only_old_can_lead

/*Regressions*/
foreach y of varlist `outcomes' {

   /*Adding Replace condition for outreg2*/ 
   if "`y'" == "bridging"{
   loc rcond replace
   }
   else{
   loc rcond
   }

/*Regression with District FE and Controls*/
  reg `y' fam_num_ln `study_controls' `district_fe' `controls'  [pw = inv_prob] , r cluster(chiefcode)

  outreg2 using "$SL_out/chiefs_modernization_appendix.tex", `rcond'  tex(frag) keep(fam_num_ln amalgamation n_chiefs) dec(`dec')  ctitle("`y'") nonotes noaster nocons label  addtext(District Fixed Effects, YES, Demographic controls, YES)

}
}

/*-----------------------------------------------------------------------------
Tables J: Robustness to Elites Measure
-----------------------------------------------------------------------------*/

loc run = 0
if `run' == 1{
  
/*Getting Outcomes at Chiefdom of Birth*/
use $SL_data/chiefs_nps_birth_rr.dta, replace

lab var amalgamation "Amalgamation"
lab var n_chiefs "Number of chiefs recalled"

lab var role_pc "Paramount or section chief in household"
lab var member "Member of ruling family"
lab var role_headman "Headman in household"

loc outcomes primary wealth nicehouse respect_authority bridging bonding collective

/*Regressions*/
foreach y of varlist `outcomes' {

  /*Generating Summary Statistics for Table 1*/
  mean `y' if missing(fam_cat) ==0

  matrix define M = e(b)
  loc mean = round(M[1,1],0.001)

  tabstat `y' [fw = round(inv_prob) ], by(fam_cat) stat(mean sd)
  
/*Regression with District FE and Controls*/
  reg `y' fam_num_ln `study_controls' `district_fe' `controls' `elite'  [pw = inv_prob] , r cluster(chiefcode)

   /*Adding Replace condition for outreg2*/ 
   if "`y'" == "primary"{
   loc rcond replace
   }
   else{
   loc rcond
   }

  outreg2 using "$SL_out/chiefs_nps_tableJa_rr.tex", `rcond'  tex(frag) drop(`controls' `district_fe') dec(`dec')  ctitle("`y'") nonotes noaster nocons label  addtext(District fixed effects, YES, Demographic controls, YES)

}


/*Kill Run Loop*/
}

loc run = 0
if `run' == 1{
  
use $SL_data/chiefs_nps_birth_rr.dta, clear

loc study_controls n_chiefs amalgamation
loc district_fe dist? dist??
loc elite member role_pc role_headman

collapse (mean) `elite' [fw = round(inv_prob)], by(chiefcode fam_num_ln `study_controls' `district_fe')

loc dec =3

foreach y of varlist `elite'{
  
 reg `y' fam_num_ln `study_controls'  `district_fe' , r 
   if "`y'" == "member"{
outreg2 using "$SL_out/chiefs_tableJb.tex", replace  tex(frag) drop(`district_fe' ) dec(`dec') ctitle("`y'") noaster nonotes nocons addtext(District fixed effects, NO)
}
 else{
outreg2 using "$SL_out/chiefs_tableJb.tex",  tex(frag) drop( `district_fe') dec(`dec')  ctitle("`y'") nonotes noaster  nocons 
}
}

/*Kill Run Loop*/
}

/*------------------------------------
Table 13B: Linkages to Chiefdom Elite
-------------------------------------*/

loc run = 1
if `run' == 1{
  
use $SL_data/chiefs_nps_birth_rr.dta, replace

loc outcomes primary wealth nicehouse

loc dec = 3

loc controls female age age2 ethnicity*
loc elite role_pc member role_headman

/*Preparing Variables*/
foreach e of varlist `elite' {
  gen `e'_int = `e'*fam_num_ln
}

lab var role_pc_int "Paramount or section chief in household $\times$ \ln(\# families)"
lab var member_int "Ruling family member $\times$ \ln(\# families)"
lab var role_headman_int "Headman in household $\times$ \ln(\# families)"

/*Regressions*/
foreach e of varlist `elite' {

loc counter = 0
foreach y of varlist `outcomes' {

xi: areg `y' `e' `e'_int `controls' [pw = inv_prob] , absorb(chiefcode) r cluster(chiefcode)

    /*Calculating Effects at p75 and p25 of number of families*/
    lincom  `e' + `e'_int*2.0412203
    loc p75b = round(r(estimate),0.001)
    loc p75se = round(r(se),0.001)

    lincom  `e' + `e'_int*.58778666
    loc p25b = round(r(estimate),0.001)
    loc p25se = round(r(se),0.001)

    lincom  `e'_int*2.0412203 - `e'_int*.58778666 
    loc diffb = round(r(estimate),0.001)
    loc diffse = round(r(se),0.001)

loc counter = `counter' + 1

if `counter' == 1{
  loc command replace
}
else{
  loc command
}

outreg2 using "$SL_out/chiefs_tableJc_`e'.tex", `command' tex(frag) drop(`controls' `district_fe' `study_controls') dec(`dec')  ctitle("`y'") addtext(Chiefdom fixed effects, YES, Demographic controls, YES, Linkage effect at 7.7 families, `p75b' , se, `p75se' ,  Linkage Effect at 1.8 families, `p25b' , se, `p25se' , Difference, `diffb' , se, `diffse' ) nonotes  noaster  nocons  sortvar(`elite')

}

}

/*Kill Run Loop*/
}

/*-----------------------------------------------------------------------------
Tables I2: Robustness to Elites Measure
-----------------------------------------------------------------------------*/

loc run = 1
if `run' == 1{
  
/*Getting Outcomes at Chiefdom of Birth*/
use $SL_data/chiefs_nps_birth_rr.dta, replace

lab var amalgamation "Amalgamation"
lab var n_chiefs "Number of chiefs recalled"

lab var role_pc "Paramount or section chief in household"
lab var member "Member of ruling family"
lab var role_headman "Headman in household"

replace fam_num = fam_num+1 if inlist(chiefcode,2101,2306,2404,2405,2503,2307,1110)
replace fam_num_ln = ln(fam_num)

loc outcomes primary wealth nicehouse respect_authority bridging bonding collective

/*Regressions*/
foreach y of varlist `outcomes' {

  /*Generating Summary Statistics for Table 1*/
  mean `y' if missing(fam_cat) ==0

  matrix define M = e(b)
  loc mean = round(M[1,1],0.001)

  tabstat `y' [fw = round(inv_prob) ], by(fam_cat) stat(mean sd)
  
/*Regression with District FE and Controls*/
  reg `y' fam_num_ln `study_controls' `district_fe' `controls'  [pw = inv_prob] , r cluster(chiefcode)

   /*Adding Replace condition for outreg2*/ 
   if "`y'" == "primary"{
   loc rcond replace
   }
   else{
   loc rcond
   }

  outreg2 using "$SL_out/chiefs_nps_tableI2_rr.tex", `rcond'  tex(frag) drop(`controls' `district_fe') dec(`dec')  ctitle("`y'") nonotes noaster nocons label  addtext(District fixed effects, YES, Demographic controls, YES)

}


/*Kill Run Loop*/
}




log close
